summaryrefslogtreecommitdiff
path: root/include/m_protosvc.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/m_protosvc.h')
-rw-r--r--include/m_protosvc.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/include/m_protosvc.h b/include/m_protosvc.h
index e6f1df3ab2..031622a3a5 100644
--- a/include/m_protosvc.h
+++ b/include/m_protosvc.h
@@ -735,12 +735,13 @@ struct PROTOFILERESUME
struct PROTORECVEVENT
{
- uint32_t flags; // combination of PREF_*
- uint32_t timestamp; // unix time
- char* szMessage; // message body in utf8
- LPARAM lParam; // extra space for the network level protocol module
- const char* szMsgId; // server message id, optional, should be NULL otherwise
- // ignored for protocols without PF4_SERVERMSGID in GetCaps()
+ uint32_t flags; // combination of PREF_*
+ uint32_t timestamp; // unix time
+ char* szMessage; // message body in utf8
+ LPARAM lParam; // extra space for the network level protocol module
+ const char* szMsgId; // server message id, optional, should be NULL otherwise
+ // ignored for protocols without PF4_SERVERMSGID in GetCaps()
+ const char *szUserId; // user id, for group chats stored in the database
};
///////////////////////////////////////////////////////////////////////////////